@@ -6,4 +6,4 @@ Package configuration.
 # Package Constants
 DEFAULT_BASE_DOMAIN = "lacework.net"
 DEFAULT_ACCESS_TOKEN_EXPIRATION = 3600
-DEFAULT_SUCCESS_RESPONSE_CODE = 200
+DEFAULT_SUCCESS_RESPONSE_CODES = [200, 201]
